From: Andrew Morton <akpm@linux-foundation.org>
To: mm-commits@vger.kernel.org,tzungbi@kernel.org,teknoraver@meta.com,serge@hallyn.com,rui.zhang@intel.com,robh@kernel.org,rafael@kernel.org,mazziesaccount@gmail.com,lukasz.luba@arm.com,lgirdwood@gmail.com,kernel@pengutronix.de,groeck@chromium.org,festevam@denx.de,daniel.lezcano@linaro.org,corbet@lwn.net,broonie@kernel.org,bleung@chromium.org,a.fatoum@pengutronix.de,akpm@linux-foundation.org
Subject: [merged mm-nonmm-stable] reboot-rename-now-misleading-__hw_protection_shutdown-symbols.patch removed from -mm tree
Date: Sun, 16 Mar 2025 22:31:59 -0700 [thread overview]
Message-ID: <20250317053200.38A8EC4CEEC@smtp.kernel.org> (raw)
The quilt patch titled
Subject: reboot: rename now misleading __hw_protection_shutdown symbols
has been removed from the -mm tree. Its filename was
reboot-rename-now-misleading-__hw_protection_shutdown-symbols.patch
This patch was dropped because it was merged into the mm-nonmm-stable branch
of git://git.kernel.org/pub/scm/linux/kernel/git/akpm/mm
------------------------------------------------------
From: Ahmad Fatoum <a.fatoum@pengutronix.de>
Subject: reboot: rename now misleading __hw_protection_shutdown symbols
Date: Mon, 17 Feb 2025 21:39:45 +0100
The __hw_protection_shutdown function name has become misleading since it
can cause either a shutdown (poweroff) or a reboot depending on its
argument.
To avoid further confusion, let's rename it, so it doesn't suggest that a
poweroff is all it can do.
Link: https://lkml.kernel.org/r/20250217-hw_protection-reboot-v3-5-e1c09b090c0c@pengutronix.de
Signed-off-by: Ahmad Fatoum <a.fatoum@pengutronix.de>
Reviewed-by: Tzung-Bi Shih <tzungbi@kernel.org>
Cc: Benson Leung <bleung@chromium.org>
Cc: Daniel Lezcano <daniel.lezcano@linaro.org>
Cc: Fabio Estevam <festevam@denx.de>
Cc: Guenter Roeck <groeck@chromium.org>
Cc: Jonathan Corbet <corbet@lwn.net>
Cc: Liam Girdwood <lgirdwood@gmail.com>
Cc: Lukasz Luba <lukasz.luba@arm.com>
Cc: Mark Brown <broonie@kernel.org>
Cc: Matteo Croce <teknoraver@meta.com>
Cc: Matti Vaittinen <mazziesaccount@gmail.com>
Cc: "Rafael J. Wysocki" <rafael@kernel.org>
Cc: Rob Herring (Arm) <robh@kernel.org>
Cc: Rui Zhang <rui.zhang@intel.com>
Cc: Sascha Hauer <kernel@pengutronix.de>
Cc: "Serge E. Hallyn" <serge@hallyn.com>
Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
---
include/linux/reboot.h | 8 ++++----
kernel/reboot.c | 8 ++++----
2 files changed, 8 insertions(+), 8 deletions(-)
--- a/include/linux/reboot.h~reboot-rename-now-misleading-__hw_protection_shutdown-symbols
+++ a/include/linux/reboot.h
@@ -188,17 +188,17 @@ extern void orderly_reboot(void);
*/
enum hw_protection_action { HWPROT_ACT_SHUTDOWN, HWPROT_ACT_REBOOT };
-void __hw_protection_shutdown(const char *reason, int ms_until_forced,
- enum hw_protection_action action);
+void __hw_protection_trigger(const char *reason, int ms_until_forced,
+ enum hw_protection_action action);
static inline void hw_protection_reboot(const char *reason, int ms_until_forced)
{
- __hw_protection_shutdown(reason, ms_until_forced, HWPROT_ACT_REBOOT);
+ __hw_protection_trigger(reason, ms_until_forced, HWPROT_ACT_REBOOT);
}
static inline void hw_protection_shutdown(const char *reason, int ms_until_forced)
{
- __hw_protection_shutdown(reason, ms_until_forced, HWPROT_ACT_SHUTDOWN);
+ __hw_protection_trigger(reason, ms_until_forced, HWPROT_ACT_SHUTDOWN);
}
/*
--- a/kernel/reboot.c~reboot-rename-now-misleading-__hw_protection_shutdown-symbols
+++ a/kernel/reboot.c
@@ -1008,7 +1008,7 @@ static void hw_failure_emergency_schedul
}
/**
* __hw_protection_shutdown - Trigger an emergency system shutdown or reboot
*
* @reason: Reason of emergency shutdown or reboot to be printed.
* @ms_until_forced: Time to wait for orderly shutdown or reboot before
@@ -1022,8 +1022,8 @@ static void hw_failure_emergency_schedul
* pending even if the previous request has given a large timeout for forced
* shutdown/reboot.
*/
-void __hw_protection_shutdown(const char *reason, int ms_until_forced,
- enum hw_protection_action action)
+void __hw_protection_trigger(const char *reason, int ms_until_forced,
+ enum hw_protection_action action)
{
static atomic_t allow_proceed = ATOMIC_INIT(1);
@@ -1043,7 +1043,7 @@ void __hw_protection_shutdown(const char
else
orderly_poweroff(true);
}
-EXPORT_SYMBOL_GPL(__hw_protection_shutdown);
+EXPORT_SYMBOL_GPL(__hw_protection_trigger);
static int __init reboot_setup(char *str)
{
_
Patches currently in -mm which might be from a.fatoum@pengutronix.de are
reply other threads:[~2025-03-17 5:32 UTC|newest]
Thread overview: [no followups] expand[flat|nested] mbox.gz Atom feed
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20250317053200.38A8EC4CEEC@smtp.kernel.org \
--to=akpm@linux-foundation.org \
--cc=a.fatoum@pengutronix.de \
--cc=bleung@chromium.org \
--cc=broonie@kernel.org \
--cc=corbet@lwn.net \
--cc=daniel.lezcano@linaro.org \
--cc=festevam@denx.de \
--cc=groeck@chromium.org \
--cc=kernel@pengutronix.de \
--cc=lgirdwood@gmail.com \
--cc=lukasz.luba@arm.com \
--cc=mazziesaccount@gmail.com \
--cc=mm-commits@vger.kernel.org \
--cc=rafael@kernel.org \
--cc=robh@kernel.org \
--cc=rui.zhang@intel.com \
--cc=serge@hallyn.com \
--cc=teknoraver@meta.com \
--cc=tzungbi@kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -1008,7 +1008,7 @@ static void hw_failure_emergency_schedul
}
/**
- * __hw_protection_shutdown - Trigger an emergency system shutdown or reboot
+ * __hw_protection_trigger - Trigger an emergency system shutdown or reboot
*
* @reason: Reason of emergency shutdown or reboot to be printed.
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.